@@ -169,7 +169,7 @@ getMidpoints <- function(data,
 #' (e.g., mom, dad, spouse) and join them into the main connection table. This supports
 #' relative-specific positioning in downstream layout functions like `calculateConnections()`.
 #'
-#' @inheritParams ggpedigree
+#' @inheritParams ggPedigree
 #' @param connections A `data.frame` containing the individuals and their associated relative IDs.
 #' @param relativeIDvar Character. Name of the column in `connections` for the relative ID variable.
 #' @param x_name Character. Name of the new column to store the x-coordinate of the relative.
@@ -241,6 +241,9 @@ getRelativeCoordinates <- function(ped,
 
   return(rel_connections)
 }
+
+
+
 #' Generate a symmetric key for two IDs
 #'
 #' This function generates a symmetric key for two IDs, ensuring that the order of the IDs does not matter.
@@ -252,8 +255,8 @@ getRelativeCoordinates <- function(ped,
 #' @return A string representing the symmetric key
 #' @keywords internal
 #' @importFrom dplyr if_else
-
-makeSymmetricKey <- function(id1, id2, sep = ".") {
+#' @aliases makeSymmetricKey
+.makeSymmetricKey <- function(id1, id2, sep = ".") {
   if (missing(id1) || missing(id2)) {
     stop("Both id1 and id2 must be provided.")
   }
@@ -286,3 +289,6 @@ makeSymmetricKey <- function(id1, id2, sep = ".") {
     paste0(id2, sep, id1)
   )
 }
+
+#' @rdname dot-makeSymmetricKey
+makeSymmetricKey <- .makeSymmetricKey
