@@ -159,13 +159,20 @@ ggPhenotypeByDegree.core <- function(df,
     config$annotation_coords$y_sib <- y_val_coord(".data$cnu == 1 & .data$addRel_center == 0.5")
     config$annotation_coords$y_mom <- y_val_coord(".data$cnu == 0 & .data$mtdna == 1 & .data$addRel_center == 0.5")
     config$annotation_coords$y_dad <- y_val_coord(".data$cnu == 0 & .data$mtdna == 0 & .data$addRel_center == 0.5")
-    config$annotation_coords$annotation_mom_x <- config$annotation_coords$x_mom + config$annotate_x_shift * config$annotation_coords$x_mom
-    config$annotation_coords$annotation_sib_x <- config$annotation_coords$x_sib + config$annotate_x_shift * config$annotation_coords$x_sib
-    config$annotation_coords$annotation_dad_x <- config$annotation_coords$x_dad + config$annotate_x_shift * config$annotation_coords$x_dad
-    config$annotation_coords$annotation_sib_y <- config$annotation_coords$y_sib + config$annotate_y_shift * config$annotation_coords$y_sib
-    config$annotation_coords$annotation_mom_y <- config$annotation_coords$y_mom + config$annotate_y_shift * config$annotation_coords$y_mom
-    config$annotation_coords$annotation_dad_y <- config$annotation_coords$y_dad + config$annotate_y_shift * config$annotation_coords$y_dad
-    config$annotation_coords$df_point <- df |> dplyr::filter(.data$cnu == 1, .data$addRel_center == .5)
+    config$annotation_coords$annotation_mom_x <- config$annotation_coords$x_mom +
+      config$annotate_x_shift * config$annotation_coords$x_mom
+    config$annotation_coords$annotation_sib_x <- config$annotation_coords$x_sib +
+      config$annotate_x_shift * config$annotation_coords$x_sib
+    config$annotation_coords$annotation_dad_x <- config$annotation_coords$x_dad +
+      config$annotate_x_shift * config$annotation_coords$x_dad
+    config$annotation_coords$annotation_sib_y <- config$annotation_coords$y_sib +
+      config$annotate_y_shift * config$annotation_coords$y_sib
+    config$annotation_coords$annotation_mom_y <- config$annotation_coords$y_mom +
+      config$annotate_y_shift * config$annotation_coords$y_mom
+    config$annotation_coords$annotation_dad_y <- config$annotation_coords$y_dad +
+      config$annotate_y_shift * config$annotation_coords$y_dad
+    config$annotation_coords$df_point <- df |>
+      dplyr::filter(.data$cnu == 1, .data$addRel_center == .5)
   } else {
     config$annotation_coords <- NULL
   }
@@ -251,8 +258,6 @@ ggPhenotypeByDegree.core <- function(df,
   }
   # naming
 
-
-
   if (config$apply_default_theme == TRUE) {
     core_plot <- core_plot +
       ggplot2::theme(axis.text.x = ggplot2::element_text(size = 12, angle = -65, hjust = 0)) +
@@ -267,7 +272,8 @@ ggPhenotypeByDegree.core <- function(df,
       labels = scales::trans_format("log2", scales::label_math(.5^.x, format = abs))
     ) +
       labs(
-        x = "Degree of Relatedness", y = "Correlation",
+        x = config$axis_x_label, # "Degree of Relatedness",
+        y = config$axis_y_label,
         title = config$plot_title,
         subtitle = config$plot_subtitle,
         color = config$grouping_name,
@@ -283,8 +289,9 @@ ggPhenotypeByDegree.core <- function(df,
       labels = scales::label_parse()
     ) +
       labs(
-        x = "Coefficient of Genetic Variation",
-        y = "Correlation", title = config$plot_title,
+        x = config$axis_x_label, # "Coefficient of Genetic Variation",
+        y = config$axis_y_label,
+        title = config$plot_title,
         subtitle = config$plot_subtitle,
         color = config$grouping_name,
         shape = config$grouping_name,
@@ -376,6 +383,11 @@ ggPhenotypeByDegree.core <- function(df,
   return(df)
 }
 
+#' @rdname dot-preparePhenotypeByDegreeData
+preparePhenotypeByDegreeData <- .preparePhenotypeByDegreeData
+
+
+
 #' @title Add annotates to ggplot Pedigree Plot
 #' @inheritParams ggPhenotypeByDegree
 #'
@@ -431,3 +443,6 @@ ggPhenotypeByDegree.core <- function(df,
   }
   return(p)
 }
+
+#' @rdname dot-addAnnotate
+addAnnotate <- .addAnnotate
