@@ -16,7 +16,7 @@ test_that("getDefaultPlotConfig returns expected defaults", {
   config <- getDefaultPlotConfig()
 
   expect_true(is.list(config))
-  expect_equal(length(config), 149) # Check number of default parameters
+  expect_equal(length(config), 159) # Check number of default parameters
 
   expect_equal(config$apply_default_scales, TRUE)
   expect_equal(config$apply_default_theme, TRUE)
@@ -31,13 +31,13 @@ test_that("getDefaultPlotConfig returns expected defaults", {
   expect_equal(config$segment_self_linetype, "dotdash")
   expect_equal(config$segment_self_angle, 90)
   expect_equal(config$segment_self_curvature, -0.2)
-  expect_equal(config$label_method, "ggrepel")
+  expect_equal(config$label_method, "geom_text")
   expect_equal(config$label_include, TRUE)
   expect_equal(config$tooltip_include, TRUE)
   expect_equal(config$tooltip_columns, c("ID1", "ID2", "value"))
   expect_equal(config$axis_text_angle_x, 90)
   expect_equal(config$axis_text_angle_y, 0)
-  expect_equal(config$axis_text_size, 8)
+  expect_equal(config$axis_text_size, 9)
   expect_equal(config$axis_text_color, "black")
   expect_equal(config$generation_height, 1)
   expect_equal(config$generation_width, 1)
@@ -46,6 +46,8 @@ test_that("getDefaultPlotConfig returns expected defaults", {
   expect_equal(config$outline_additional_size, 0)
   expect_equal(config$outline_multiplier, 1.25)
   expect_equal(config$point_size, 4)
+  expect_true(is.null(config$hints))
+  expect_true(is.null(config$relation))
   expect_equal(config$outline_multiplier * config$point_size, 5)
   expect_equal(
     config$outline_multiplier * config$point_size + config$outline_additional_size,
@@ -56,14 +58,20 @@ test_that("handles function_name variations", {
   config1 <- getDefaultPlotConfig(function_name = "ggpedigree")
   config2 <- getDefaultPlotConfig(function_name = "ggPedigreeInteractive")
   config3 <- getDefaultPlotConfig(function_name = "ggrelatednessmatrix")
+
+
   expect_true(is.list(config1))
   expect_true(is.list(config2))
   expect_true(is.list(config3))
   expect_equal(length(config1), length(config2))
   expect_equal(length(config1), length(config3))
 
-  expect_equal(config1$label_method, "ggrepel")
+  expect_equal(config1$label_method, "geom_text")
   expect_equal(config2$label_method, "geom_text")
+  expect_equal(config2$label_nudge_y_flip, TRUE)
+  expect_equal(config3$label_nudge_y_flip, FALSE)
+  expect_equal(config1$label_nudge_y, config2$label_nudge_y)
+  expect_equal(config1$label_nudge_y, config3$label_nudge_y)
   expect_true(config2$return_widget)
   expect_true(config2$return_interactive)
   expect_false(config2$return_static)
@@ -113,11 +121,14 @@ test_that("buildPlotConfig merges valid subset overrides correctly", {
     result$segment_linewidth,
     default_config$segment_linewidth
   )
+  expect_equal(result$label_nudge_y, -0.15)
+  expect_equal(result$label_nudge_y, -1 * default_config$label_nudge_y)
 })
 test_that("buildPlotConfig returns a list", {
-  default_config <- getDefaultPlotConfig(function_name = "ggPedigree")
+  default_config <- getDefaultPlotConfig(function_name = "ggrelatednessmatrix")
   custom <- list(point_size = 2)
 
   result <- buildPlotConfig(default_config, custom)
+  expect_equal(result$label_nudge_y, 0.15)
   expect_true(is.list(result))
 })
